package com.compdfkit.pdfviewer;

import androidx.appcompat.app.AppCompatActivity;
import androidx.core.content.ContextCompat;
import androidx.core.graphics.drawable.DrawableCompat;

import android.content.Intent;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Canvas;
import android.graphics.drawable.BitmapDrawable;
import android.graphics.drawable.Drawable;
import android.net.Uri;
import android.os.Build;
import android.os.Bundle;
import android.os.Environment;
import android.provider.Settings;
import android.widget.Toast;

import com.compdfkit.core.document.CPDFDocument;
import com.compdfkit.core.utils.ColorUtils;
import com.compdfkit.core.watermark.CPDFImageWatermark;
import com.compdfkit.core.watermark.CPDFTextWatermark;
import com.compdfkit.core.watermark.CPDFWatermark;
import com.compdfkit.ui.reader.CPDFReaderView;

import java.io.File;

public class MainActivity extends AppCompatActivity {

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

//        if (!(Build.VERSION.SDK_INT < Build.VERSION_CODES.R || Environment.isExternalStorageManager())) {
//            Intent intent = new Intent(Settings.ACTION_MANAGE_ALL_FILES_ACCESS_PERMISSION);
//            intent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
//            startActivity(intent);
//        }

        File PDFFile = new File("/storage/emulated/0/TestPDFs/01.pdf");
        Uri PDFUri = Uri.fromFile(PDFFile);

        CPDFDocument document = new CPDFDocument(this);
        CPDFDocument.PDFDocumentError error = document.open(PDFFile.getAbsolutePath());

        CPDFReaderView readerView;
        readerView = (CPDFReaderView) findViewById(R.id.pdf_view);

        if (error == CPDFDocument.PDFDocumentError.PDFDocumentErrorPassword) {
            error = document.open(PDFUri, "password");
        } else if (error == CPDFDocument.PDFDocumentError.PDFDocumentErrorSuccess) {
            Toast.makeText(this, "File:" + document.getFileName() + " open success.", Toast.LENGTH_SHORT).show();
        } else {
            Toast.makeText(this, "File failed.", Toast.LENGTH_SHORT).show();
        }

        readerView.setPDFDocument(document);
        readerView.setVerticalMode(true);
        readerView.setDoublePageMode(false);

        int watermarkIndex = 0;
        CPDFWatermark watermark = null;

        try {
            watermark = document.getWatermark(watermarkIndex);
            if (watermark != null)
                watermark.clear();
        } finally {
            if (watermark != null && watermark.isValid()) {
                watermark.release();
            }
        }

        Drawable drawable = ContextCompat.getDrawable(this, R.drawable.pdf);

        CPDFImageWatermark imgWatermark = (CPDFImageWatermark)
                document.createWatermark(CPDFWatermark.Type.WATERMARK_TYPE_IMG);

        assert drawable != null;
        Bitmap bitmap = Bitmap.createBitmap(drawable.getIntrinsicWidth(), drawable.getIntrinsicHeight(), Bitmap.Config.ARGB_8888);
        Canvas canvas = new Canvas(bitmap);
        drawable.setBounds(0, 0, canvas.getWidth(), canvas.getHeight());
        drawable.draw(canvas);

        try {
            if (imgWatermark != null && imgWatermark.isValid()) {
                imgWatermark.setText("RA"); //设置文本
                imgWatermark.setFontName("Helvetica"); //设置字体
                imgWatermark.setImage(bitmap, 100, 100);
                imgWatermark.setTextRGBColor(ColorUtils.parseColor(new int[] { 102, 204, 255 }));
                imgWatermark.setOpacity(0.5f);
                imgWatermark.setRotation(0.785f);
                imgWatermark.setFontSize(100);
                imgWatermark.setFront(false);
                imgWatermark.setVertalign(CPDFWatermark.Vertalign.WATERMARK_VERTALIGN_CENTER);
                imgWatermark.setHorizalign(CPDFWatermark.Horizalign.WATERMARK_HORIZALIGN_CENTER);
                imgWatermark.setVertOffset(0);
                imgWatermark.setHorizOffset(0);
                imgWatermark.setScale(0.2f);
                imgWatermark.setPages("1,3-5");
                imgWatermark.setFullScreen(true);
                imgWatermark.setHorizontalSpacing(100);
                imgWatermark.setVerticalSpacing(100);
                imgWatermark.update();
            }
        } finally {
            if (imgWatermark != null && imgWatermark.isValid()) {
                imgWatermark.release();
            }
        }

//        CPDFTextWatermark textWatermark = (CPDFTextWatermark)
//                document.createWatermark(CPDFWatermark.Type.WATERMARK_TYPE_TEXT);
//        try {
//            if (textWatermark != null && textWatermark.isValid()) {
//                textWatermark.setText("RA"); //设置文本
//                textWatermark.setFontName("Helvetica"); //设置字体
//                textWatermark.setTextRGBColor(ColorUtils.parseColor(new int[] { 102, 204, 255 }));
//                textWatermark.setOpacity(1f);
//                textWatermark.setFontSize(100);
//                textWatermark.setFront(false);
//                textWatermark.setVertalign(CPDFWatermark.Vertalign.WATERMARK_VERTALIGN_CENTER);
//                textWatermark.setHorizalign(CPDFWatermark.Horizalign.WATERMARK_HORIZALIGN_CENTER);
//                textWatermark.setVertOffset(0);
//                textWatermark.setHorizOffset(0);
//                textWatermark.setScale(1.0f);
//                textWatermark.setPages("1,3-5");
//                textWatermark.setFullScreen(true);
//                textWatermark.setHorizontalSpacing(10);
//                textWatermark.setVerticalSpacing(10);
//                textWatermark.update();
//            }
//        } finally {
//            if (textWatermark != null && textWatermark.isValid()) {
//                textWatermark.release();
//            }
//        }
    }
}