package com.compdfkit.pdfviewer.customview;

import android.content.Context;
import android.content.res.TypedArray;
import android.util.AttributeSet;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.ImageButton;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.constraintlayout.widget.ConstraintLayout;

import com.compdfkit.pdfviewer.R;

public class WatermarkView extends ConstraintLayout {
    private Context currentContext;
    private LayoutInflater inflater;
    private View currentView;

    private ImageButton rollingHandle;

    private boolean imageMode = false;

    public WatermarkView(@NonNull Context context) {
        this(context, null);
    }

    public WatermarkView(@NonNull Context context, @Nullable AttributeSet attrs) {
        this(context, attrs, 0);
    }

    public WatermarkView(@NonNull Context context, @Nullable AttributeSet attrs, int defStyleAttr) {
        this(context, attrs, defStyleAttr, 0);
    }

    public WatermarkView(@NonNull Context context, @Nullable AttributeSet attrs, int defStyleAttr, int defStyleRes) {
        super(context, attrs, defStyleAttr, defStyleRes);
        init(context, attrs);
    }

    private void init(Context context, AttributeSet attrs) {
        currentContext = context;
        inflater = (LayoutInflater) currentContext.getSystemService(Context.LAYOUT_INFLATER_SERVICE);

        TypedArray attribute = currentContext.obtainStyledAttributes(attrs, R.styleable.WatermarkView);
        imageMode = attribute.getBoolean(R.styleable.WatermarkView_image_mode, false);

        setImageMode(imageMode);
    }

    public void setImageMode(@NonNull Boolean isImageMode) {
        if (isImageMode) {
            currentView = inflater.inflate(R.layout.watermark_image_view, this, true);
        } else {
            currentView = inflater.inflate(R.layout.watermark_text_view, this, true);
        }
        Log.d("WatermarkView", "Current watermark mode: " + imageMode);
        rollingHandle = currentView.findViewById(R.id.watermark_handle);

        rollingHandle.setOnClickListener(new OnClickListener() {
            @Override
            public void onClick(View view) {

            }
        });
    }
}
